@@ -4,6 +4,9 @@ from typing import Union, Tuple, List, Iterable, Dict
 from ..SentenceTransformer import SentenceTransformer
 import logging
 
+
+logger = logging.getLogger(__name__)
+
 class SoftmaxLoss(nn.Module):
     """
     This loss was used in our SBERT publication (https://arxiv.org/abs/1908.10084) to train the SentenceTransformer
@@ -22,7 +25,7 @@ class SoftmaxLoss(nn.Module):
         from sentence_transformers.readers import InputExample
 
         model = SentenceTransformer('distilbert-base-nli-mean-tokens')
-        train_examples = [InputExample(InputExample(texts=['First pair, sent A', 'First pair, sent B'], label=0),
+        train_examples = [InputExample(texts=['First pair, sent A', 'First pair, sent B'], label=0),
             InputExample(texts=['Second Pair, sent A', 'Second Pair, sent B'], label=3)]
         train_dataset = SentencesDataset(train_examples, model)
         train_dataloader = DataLoader(train_dataset, shuffle=True, batch_size=train_batch_size)
@@ -49,7 +52,7 @@ class SoftmaxLoss(nn.Module):
             num_vectors_concatenated += 1
         if concatenation_sent_multiplication:
             num_vectors_concatenated += 1
-        logging.info("Softmax loss: #Vectors concatenated: {}".format(num_vectors_concatenated))
+        logger.info("Softmax loss: #Vectors concatenated: {}".format(num_vectors_concatenated))
         self.classifier = nn.Linear(num_vectors_concatenated * sentence_embedding_dimension, num_labels)
 
     def forward(self, sentence_features: Iterable[Dict[str, Tensor]], labels: Tensor):
@@ -76,4 +79,4 @@ class SoftmaxLoss(nn.Module):
             loss = loss_fct(output, labels.view(-1))
             return loss
         else:
-            return reps, output
\ No newline at end of file
+            return reps, output
